@@ -1,19 +1,18 @@
 class Cipher:
 
-    def __init__(self, key, original_text):
-        self.text = original_text
+    def __init__(self, key):
         self.key = 42
 
-    def simple_xor_encrypt(self, text, key):
+    def simple_xor_encrypt(self, text):
         encrypted_chars = []
         for char in text:
-            encrypted_char = ord(char) ^ key
+            encrypted_char = ord(char) ^ self.key
             encrypted_chars.append(encrypted_char)
         return bytes(encrypted_chars)
 
-    def simple_xor_decrypt(self, encrypted_text, key):
+    def simple_xor_decrypt(self, encrypted_text):
         decrypted_chars = []
         for encrypted_char in encrypted_text:
-            decrypted_char = chr(encrypted_char ^ key)
+            decrypted_char = chr(encrypted_char ^ self.key)
             decrypted_chars.append(decrypted_char)
         return "".join(decrypted_chars)
